@@ -1,12 +1,12 @@
 # ABSTRACT: Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 package PONAPI::Client;
 
-our $VERSION = '0.002007';
+our $VERSION = '0.002008';
 
 use Moose;
 
 use Hijk;
-use JSON::XS qw( decode_json );
+use JSON::MaybeXS qw( decode_json );
 
 use PONAPI::Client::Request::Create;
 use PONAPI::Client::Request::CreateRelationships;
@@ -200,7 +200,7 @@ PONAPI::Client - Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 
 =head1 VERSION
 
-version 0.002007
+version 0.002008
 
 =head1 SYNOPSIS
 
@@ -731,7 +731,7 @@ Brian Fraser <hugmeir@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2017 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
