@@ -3,7 +3,7 @@ package PONAPI::Client::Request;
 
 use Moose::Role;
 
-use JSON::XS qw< encode_json >;
+use JSON::MaybeXS qw< encode_json >;
 
 use PONAPI::Utils::URI qw< to_uri >;
 
@@ -92,7 +92,7 @@ PONAPI::Client::Request - request class
 
 =head1 VERSION
 
-version 0.002007
+version 0.002008
 
 =head1 AUTHORS
 
@@ -114,7 +114,7 @@ Brian Fraser <hugmeir@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2017 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
